const path = require('path');
const fetch = require('node-fetch');
const fs = require('fs-extra');
const ora = require('ora');

const crawler = require('../crawlers/index.js');
const { walk } = require('../utils.js');

async function getExclusions(site) {
  const spinner = ora('Filtering exclusions').start();
  const api = `https://raw.githubusercontent.com/bangumi-data/helper/master/exclusions/${site}.txt`;
  const remote = await fetch(api).then(res => (res.ok ? res.text() : ''));
  const exclusionFile = path.resolve(__dirname, `../../exclusions/${site}.txt`);
  const local = await fs.readFile(exclusionFile).catch(() => '');
  spinner.stop();
  return [...new Set(`${remote}\n${local}`.trim().split(/\r?\n/))];
}

async function getExistences(input, site) {
  const spinner = ora('Filtering existences').start();
  const files = await walk(input, item => /\d\d\.json$/.test(item));
  const items = await Promise.all(files.map(file => fs.readJson(file)))
    .then(results => [].concat(...results));
  spinner.stop();
  return [].concat(...items.map(item => item.sites))
    .filter(x => typeof x === 'object')
    .filter(x => x.site === site)
    .map(x => x.id);
}

module.exports = async function hokan({ site, input, output }) {
  if (!crawler[site] || !crawler[site].getAll) {
    throw new Error(`${site} is not supported now.`);
  }
  const items = await crawler[site].getAll();
  console.log(`Total: ${items.length} items`);
  const exclusions = await getExclusions(site);
  const existences = await getExistences(input, site);
  const todos = items
    .filter(item => !exclusions.includes(item.id))
    .filter(item => !existences.includes(item.id))
    .map(item => Object.assign({ copyIt: { site, id: item.id } }, item));
  console.log(`After filtering: ${todos.length} items`);
  if (!todos.length) {
    console.log('There is no bangumi needs hokan');
    return;
  }
  const outputFile = path.resolve(output, `0000/${site}.json`);
  await fs.outputJson(outputFile, todos, { spaces: 2 });
  console.log(`Data is outputed to ${outputFile}`);
};
